#
# spec file for package sca-patterns-suma
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sca_common sca
%define patdirbase /usr/lib/%{sca_common}
%define patdir %{patdirbase}/patterns
%define patuser root
%define patgrp root
%define patmode 755
%define category suma

Name:           sca-patterns-suma
Version:        1.5.1
Release:        1.4
Summary:        Supportconfig Analysis Patterns for SUSE Manager
License:        GPL-2.0-only
URL:            https://github.com/g23guy/sca-patterns-suma
Group:          System/Monitoring
Source:         %{name}-%{version}.tar.gz
BuildRequires:  fdupes
Requires:       sca-patterns-base >= 1.5.0
BuildArch:      noarch

%description
Supportconfig Analysis (SCA) appliance patterns to identify known
issues relating to all versions of SUSE Manager (SUMA)

See %{_docdir}/sca-patterns-base/COPYING.GPLv2

%prep
%setup -q

%build

%install
pwd;ls -la
install -d %{buildroot}/%{patdir}/%{category}
install -d %{buildroot}/%{patdir}/%{category}/suma12all
install -d %{buildroot}/%{patdir}/%{category}/suma17all
install -d %{buildroot}/%{patdir}/%{category}/suma21all
install -m %{patmode} patterns/%{category}/suma12all/* %{buildroot}/%{patdir}/%{category}/suma12all
install -m %{patmode} patterns/%{category}/suma17all/* %{buildroot}/%{patdir}/%{category}/suma17all
install -m %{patmode} patterns/%{category}/suma21all/* %{buildroot}/%{patdir}/%{category}/suma21all
%fdupes %{buildroot}

%files
%defattr(-,%{patuser},%{patgrp})
%dir %{patdirbase}
%dir %{patdir}
%dir %{patdir}/%{category}
%dir %{patdir}/%{category}/suma12all
%dir %{patdir}/%{category}/suma17all
%dir %{patdir}/%{category}/suma21all
%attr(%{patmode},%{patuser},%{patgrp}) %{patdir}/%{category}/suma12all/*
%attr(%{patmode},%{patuser},%{patgrp}) %{patdir}/%{category}/suma17all/*
%attr(%{patmode},%{patuser},%{patgrp}) %{patdir}/%{category}/suma21all/*

%changelog
* Fri Jan 12 2024 jason.record@suse.com
- Changes to version 1.5.1
  + Changed pattern mode in spec file (bsc#1218773)
* Fri Nov  5 2021 Jason Record <jason.record@suse.com>
- Changes to updated version 1.5.0
  + Converted to python3 (bsc#1191005, SLE-21579)
* Tue Jan  2 2018 jason.record@suse.com
- Removed unnecessary %%clean from spec
* Mon Dec 18 2017 jason.record@suse.com
- Updated spec file with spec-cleaner suggestions
- Removed COPYING.GPLv2
* Fri Sep  8 2017 jason.record@suse.com
- New Security Pattern
  suma21all/python-pycrypto_SUSE-SU-2017_2350-1_suma-2.1.py
* Mon Jun 13 2016 jason.record@suse.com
- New Security Pattern
  suma21all/bind_SUSE-SU-2016_1541-1_suma-2.1.py
* Fri Apr 22 2016 jrecord@suse.com
- New Security Pattern
  suma21all/openssl_SUSE-SU-2016_1057-1_suma-2.1.py
* Fri Aug  7 2015 jrecord@suse.com
- New Security Pattern
  suma21all/oracle-update_SUSE-SU-2015_1353-1_suma-2.1.py
* Thu Jul  9 2015 jrecord@suse.com
- New Security Pattern
  suma17all/openssl_SUSE-SU-2015_1182-1_suma-1.7.py
* Fri May 22 2015 jrecord@suse.com
- New Pattern
  suma17all/susemanager_SUSE-SU-2015_0928-1_suma-1.7.py
* Thu Feb 26 2015 jrecord@suse.com
- New Pattern
  suma17all/java_SUSE-SU-2015_0343-2_suma-1.7.py
- Fixed updateStatus for suma17all/spacewalk-branding_SUSE-SU-2014_1394-1_1.7.py
* Fri Dec  5 2014 jrecord@suse.com
- New Patterns
  suma12all/manager_SUSE-SU-2011_0653-1_suma-1.2.py
  suma21all/proxy_SUSE-SU-2011_0648-1_suma-2.1.py
* Fri Dec  5 2014 jrecord@suse.com
- New Patterns
  suma12all/auditlog-keeper_SUSE-SU-2012_0958-1_suma-1.2.py
  suma12all/cobbler_SUSE-SU-2012_0552-1_suma-1.2.py
  suma12all/cobbler_SUSE-SU-2012_0814-1_suma-1.2.py
  suma12all/oracle-update_SUSE-SU-2012_0765-1_suma-1.2.py
  suma12all/oracle-update_SUSE-SU-2012_1020-1_suma-1.2.py
  suma17all/oracle-update_SUSE-SU-2012_1020-1_suma-1.7.py
* Thu Dec  4 2014 jrecord@suse.com
- Added SUMA 1.2 directory
* Thu Dec  4 2014 jrecord@suse.com
- New Patterns
  suma12all/manager_SUSE-SU-2013_0841-1_suma-1.2.py
  suma12all/oracle-update_SUSE-SU-2013_0811-1_suma-1.2.py
  suma12all/oracle-update_SUSE-SU-2013_1448-1_suma-1.2.py
  suma17all/manager_SUSE-SU-2013_0841-1_suma-1.7.py
  suma17all/oracle-update_SUSE-SU-2013_0810-1_suma-1.7.py
  suma17all/oracle-update_SUSE-SU-2013_1448-1_suma-1.7.py
  suma17all/spacewalk-java_SUSE-SU-2013_1661-1_suma-1.7.py
* Wed Dec  3 2014 jrecord@suse.com
- New Patterns
  suma17all/bash_SUSE-SU-2014_1223-1_suma-1.7.py
  suma17all/bash_SUSE-SU-2014_1247-2_suma-1.7.py
  suma17all/gnutls_SUSE-SU-2014_0445-1_suma-1.7.py
  suma17all/gnutls_SUSE-SU-2014_0758-2_suma-1.7.py
  suma17all/java_SUSE-SU-2014_0451-1_suma-1.7.py
  suma17all/java_SUSE-SU-2014_0728-1_suma-1.7.py
  suma17all/java_SUSE-SU-2014_1526-2_suma-1.7.py
  suma17all/openssl-certs_SUSE-SU-2014_0444-1_suma-1.7.py
  suma17all/openssl_SUSE-SU-2014_1387-2_suma-1.7.py
  suma17all/oracle-update_SUSE-SU-2014_0130-1_suma-1.7.py
  suma17all/spacewalk-java_SUSE-SU-2014_1339-1_suma-1.7.py
  suma17all/struts_SUSE-SU-2014_0902-1_suma-1.7.py
  suma21all/spacewalk-java_SUSE-SU-2014_1218-1_suma-2.1.py
  suma21all/spacewalk-java_SUSE-SU-2014_1342-1_suma-2.1.py
  suma21all/struts_SUSE-SU-2014_0902-1_suma-2.1.py
* Tue Dec  2 2014 jrecord@suse.com
- Changed suma17all/jabberd-7015878.py to use suma library
- New Pattern
  suma17all/spacewalk-branding_SUSE-SU-2014_1394-1_1.7.py
* Thu Nov 13 2014 jrecord@suse.com
- New Patterns
  suma17all/jabberd-7015878.py
  suma17all/master-tid-suma-7012610.py
  suma21all/jabberd-7015878.py
  suma21all/master-tid-suma-7012610.py
- Initial checkin
